diff finch/gntblist.h @ 15823:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 0e3a8505ebbe
children 66dff3dfdea6
line wrap: on
line diff
--- a/finch/gntblist.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/finch/gntblist.h	Mon Mar 19 07:01:17 2007 +0000
@@ -2,9 +2,9 @@
  * @file gntblist.h GNT BuddyList API
  * @ingroup gntui
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -35,9 +35,9 @@
 /**
  * Get the ui-functions.
  *
  * @return The GaimBlistUiOps structure populated with the appropriate functions.
  */
-GaimBlistUiOps * finch_blist_get_ui_ops(void);
+PurpleBlistUiOps * finch_blist_get_ui_ops(void);
 
 /**
  * Perform necessary initializations.
@@ -2,9 +2,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
@@ -35,9 +35,9 @@
  * Get the ui-functions.
  *
- * @return The GaimBlistUiOps structure populated with the appropriate functions.
+ * @return The PurpleBlistUiOps structure populated with the appropriate functions.
  */